Helper crate for locating a bootloader dependency on the file system.
Enums
- Failed to query project metadata.
- Failed to locate the bootloader dependency with the given name.
Functions
- Locates the dependency with the given name on the file system.